Control

Struct Control 

pub struct Control { /* private fields */ }
Control Register

Implementations

Source

impl Control

pub const ZERO: Self

Creates a new instance with a raw value of 0. Equivalent to [Self::new_with_raw_value(0)].

pub const fn raw_value(&self) -> u32

Returns the underlying raw value of this bitfield

pub const fn new_with_raw_value(value: u32) -> Control

Creates a new instance of this bitfield with the given raw value.

No checks are performed on the value, so it is possible to set bits that don’t have any accessors specified.

pub const fn builder() -> PartialControl<false, false, false>

Creates a builder for this bitfield which ensures that all writable fields are initialized.

pub const fn parity(&self) -> Result<Parity, u2>

Parity bits for a byte

pub const fn with_parity(&self, field_value: Parity) -> Self

Parity bits for a byte

pub fn set_parity(&mut self, field_value: Parity)

Parity bits for a byte

pub const fn baud_rate(&self) -> u23

Baud Rate

pub const fn with_baud_rate(&self, field_value: u23) -> Self

Baud Rate

pub fn set_baud_rate(&mut self, field_value: u23)

Baud Rate

pub const fn enable(&self) -> bool

Is this peripheral enabled

pub const fn with_enable(&self, field_value: bool) -> Self

Is this peripheral enabled

pub fn set_enable(&mut self, field_value: bool)

Is this peripheral enabled