Status

Struct Status 

pub struct Status { /* private fields */ }
Status Register

Implementations

Source

impl Status

pub const ZERO: Self

Creates a new instance with a raw value of 0. Equivalent to [Self::new_with_raw_value(0)].

pub const fn raw_value(&self) -> u32

Returns the underlying raw value of this bitfield

pub const fn new_with_raw_value(value: u32) -> Status

Creates a new instance of this bitfield with the given raw value.

No checks are performed on the value, so it is possible to set bits that don’t have any accessors specified.

pub const fn builder() -> PartialStatus<false, false>

Creates a builder for this bitfield which ensures that all writable fields are initialized.

pub const fn rx_ready(&self) -> bool

Does the RX FIFO have data?

pub const fn with_rx_ready(&self, field_value: bool) -> Self

Does the RX FIFO have data?

pub fn set_rx_ready(&mut self, field_value: bool)

Does the RX FIFO have data?

pub const fn tx_ready(&self) -> bool

Does the TX FIFO have data?

pub const fn with_tx_ready(&self, field_value: bool) -> Self

Does the TX FIFO have data?

pub fn set_tx_ready(&mut self, field_value: bool)

Does the TX FIFO have data?