pub struct Control { /* private fields */ }Expand description
Control Register
Implementations
Sourceimpl Control
impl Control
Sourcepub const ZERO: Self
pub const ZERO: Self
Creates a new instance with a raw value of 0. Equivalent to [Self::new_with_raw_value(0)].
Sourcepub const fn new_with_raw_value(value: u32) -> Control
pub const fn new_with_raw_value(value: u32) -> Control
Creates a new instance of this bitfield with the given raw value.
No checks are performed on the value, so it is possible to set bits that don’t have any accessors specified.
Sourcepub const fn builder() -> PartialControl<false, false, false>
pub const fn builder() -> PartialControl<false, false, false>
Creates a builder for this bitfield which ensures that all writable fields are initialized.
Sourcepub const fn with_parity(&self, field_value: Parity) -> Self
pub const fn with_parity(&self, field_value: Parity) -> Self
Parity bits for a byte
Sourcepub fn set_parity(&mut self, field_value: Parity)
pub fn set_parity(&mut self, field_value: Parity)
Parity bits for a byte
Sourcepub const fn with_baud_rate(&self, field_value: u23) -> Self
pub const fn with_baud_rate(&self, field_value: u23) -> Self
Baud Rate
Sourcepub fn set_baud_rate(&mut self, field_value: u23)
pub fn set_baud_rate(&mut self, field_value: u23)
Baud Rate
Sourcepub const fn with_enable(&self, field_value: bool) -> Self
pub const fn with_enable(&self, field_value: bool) -> Self
Is this peripheral enabled
Sourcepub fn set_enable(&mut self, field_value: bool)
pub fn set_enable(&mut self, field_value: bool)
Is this peripheral enabled