pub struct Status { /* private fields */ }Expand description
Status Register
Implementations
Sourceimpl Status
impl Status
Sourcepub const ZERO: Self
pub const ZERO: Self
Creates a new instance with a raw value of 0. Equivalent to [Self::new_with_raw_value(0)].
Sourcepub const fn new_with_raw_value(value: u32) -> Status
pub const fn new_with_raw_value(value: u32) -> Status
Creates a new instance of this bitfield with the given raw value.
No checks are performed on the value, so it is possible to set bits that don’t have any accessors specified.
Sourcepub const fn builder() -> PartialStatus<false, false>
pub const fn builder() -> PartialStatus<false, false>
Creates a builder for this bitfield which ensures that all writable fields are initialized.
Sourcepub const fn with_rx_ready(&self, field_value: bool) -> Self
pub const fn with_rx_ready(&self, field_value: bool) -> Self
Does the RX FIFO have data?
Sourcepub fn set_rx_ready(&mut self, field_value: bool)
pub fn set_rx_ready(&mut self, field_value: bool)
Does the RX FIFO have data?
Sourcepub const fn with_tx_ready(&self, field_value: bool) -> Self
pub const fn with_tx_ready(&self, field_value: bool) -> Self
Does the TX FIFO have data?
Sourcepub fn set_tx_ready(&mut self, field_value: bool)
pub fn set_tx_ready(&mut self, field_value: bool)
Does the TX FIFO have data?